<?php
/** Tongan (lea faka-Tonga)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Cbrown1023
 * @author Tauʻolunga
 * @author לערי ריינהארט
 */

$messages = array(
# User preference toggles
'tog-underline'            => 'Ngaahi fehokotaki ʻoku laineʻi ʻi lalo:',
'tog-highlightbroken'      => 'Ngaohi ʻa e ngaahi fehokotaki maumau ʻoku <a href="" class="new">pehē</a> (meʻa kehe ʻoku pehē <a href="" class="internal">?</a>).',
'tog-rememberpassword'     => 'Manatuʻi ʻeku kau-ki-ai ʻi he komipiuta ʻeni (for a maximum of $1 {{PLURAL:$1|day|days}})',
'tog-watchcreations'       => 'Tānaki ngaahi peesi ʻoku fakatupu ʻe au ki he hokohoko leʻo',
'tog-watchdefault'         => 'Tānaki ngaahi peesi ʻoku fatu ʻe au ki he hokohoko leʻo',
'tog-watchmoves'           => 'Tānaki ki heʻeku hokohoko leʻo ʻa e ngaahi peesi kuo ʻunu ʻe au',
'tog-watchdeletion'        => 'Tānaki ki heʻeku hokohoko leʻo ʻa e ngaahi peesi kuo tāmateʻi ʻe au',
'tog-enotifwatchlistpages' => 'Tohila mai ʻo ka liliu ha peesi ʻi heʻeku hokohoko leʻo',
'tog-enotifusertalkpages'  => 'Tohila mai ʻo ka liliu ʻa heʻeku peesi alea',
'tog-enotifminoredits'     => 'Tohila mai foki ʻo ka ʻi ai ha fatu siʻi pē',
'tog-enotifrevealaddr'     => 'Fakahā hoku tuʻasila ʻi he ngaahi tohila tala',
'tog-fancysig'             => 'Fakamoʻoniʻi tula pē (taʻefehokotaki fakamīsini)',
'tog-forceeditsummary'     => 'Tala mai kapau ʻe ʻikai te u foaki ʻa e fakanounou fatu',
'tog-watchlisthideown'     => 'Toi ʻeku ngaahi fatu mei he hokohoko leʻo',
'tog-watchlisthidebots'    => 'Toi fatu fakamīsini mei he hokohoko leʻo',
'tog-watchlisthideminor'   => 'Toi ha ngaahi fatu siʻisiʻi mei he hokohoko leʻo',
'tog-ccmeonemails'         => 'ʻAve mai ʻa e hikitatau ʻo e ngaahi tohila naʻe ʻave atu ʻe au',
'tog-diffonly'             => 'ʻOua ʻe ʻasi ha kakano peesi ʻi lalo ngaahi liliu',
'tog-showhiddencats'       => 'ʻAsi mai ʻa e ngaahi faʻahinga toi',

'underline-always'  => 'Taimi kotoa',
'underline-never'   => 'ʻIkai teitei',
'underline-default' => 'Palausa tuʻunga',

# Dates
'sunday'        => 'Sāpate',
'monday'        => 'Mōnite',
'tuesday'       => 'Tusite',
'wednesday'     => 'Pulelulu',
'thursday'      => 'Tuʻapulelulu',
'friday'        => 'Falaite',
'saturday'      => 'Tokonaki',
'sun'           => 'Sāp',
'mon'           => 'Mōn',
'tue'           => 'Tus',
'wed'           => 'Pul',
'thu'           => 'Tuʻa',
'fri'           => 'Fal',
'sat'           => 'Tok',
'january'       => 'Sānuali',
'february'      => 'Fēpueli',
'march'         => 'Maʻasi',
'april'         => 'ʻEpeleli',
'may_long'      => 'Mē',
'june'          => 'Sune',
'july'          => 'Siulai',
'august'        => 'ʻAokosi',
'september'     => 'Sēpitema',
'october'       => 'ʻOkatopa',
'november'      => 'Nōvema',
'december'      => 'Tisema',
'january-gen'   => 'Sānuali',
'february-gen'  => 'Fēpueli',
'march-gen'     => 'Maʻasi',
'april-gen'     => 'ʻEpeleli',
'may-gen'       => 'Mē',
'june-gen'      => 'Sune',
'july-gen'      => 'Siulai',
'august-gen'    => 'ʻAokosi',
'september-gen' => 'Sēpitema',
'october-gen'   => 'ʻOkatopa',
'november-gen'  => 'Nōvema',
'december-gen'  => 'Tisema',
'jan'           => 'Sān',
'feb'           => 'Fēp',
'mar'           => 'Maʻa',
'apr'           => 'ʻEpe',
'may'           => 'Mē',
'jun'           => 'Sun',
'jul'           => 'Siu',
'aug'           => 'ʻAok',
'sep'           => 'Sēp',
'oct'           => 'ʻOka',
'nov'           => 'Nōv',
'dec'           => 'Tis',

# Categories related messages
'pagecategories'           => 'Faʻahinga',
'category_header'          => 'Ngaahi kupu ʻi he faʻahinga "$1"',
'subcategories'            => 'Ngaahi faʻahinga siʻi',
'category-empty'           => "''Ko e faʻahinga ʻeni ʻoku ʻikai ʻi ai haʻane kupu pe ʻata.''",
'hidden-categories'        => 'Faʻahinga toi',
'hidden-category-category' => 'Ngaahi faʻahinga toi',
'listingcontinuesabbrev'   => ' hoko',

'about'         => 'Kau ki',
'article'       => 'Peesi kakano',
'newwindow'     => '(fakaava ʻi he matapā foʻou)',
'cancel'        => 'Kaniseli',
'moredotdotdot' => 'Hoko...',
'mypage'        => 'Peesi ʻaʻaku',
'mytalk'        => 'Alea ʻaʻaku',
'anontalk'      => 'Alea maʻa e IP´ ni',
'navigation'    => 'ʻai taumuʻa ki he…',
'and'           => '&#32;mo e',

# Cologne Blue skin
'qbfind'         => 'Kumi',
'qbbrowse'       => 'Palausa',
'qbedit'         => 'Fatu',
'qbpageoptions'  => 'Peesi koʻeni',
'qbmyoptions'    => 'Peesi ʻaʻaku',
'qbspecialpages' => 'Ngaahi peesi makehe',
'faq'            => 'Fehuʻi faʻa eke',
'faqpage'        => 'Project:Fehuʻi faʻa eke',

'errorpagetitle'    => 'Halaʻi',
'returnto'          => 'Foki ki he $1',
'tagline'           => 'Mei he {{SITENAME}}',
'help'              => 'Tokoni',
'search'            => 'Kumi',
'searchbutton'      => 'Kumi',
'go'                => 'Fai ā',
'searcharticle'     => 'Fai ā',
'history'           => 'Hisitōlia ʻo e pēsí',
'history_short'     => 'Hisitōlia',
'updatedmarker'     => 'Kuo fakafoʻoua talu ai mei heʻeku ʻaʻahi',
'printableversion'  => 'Paaki',
'permalink'         => 'Fehokotaki taumaʻu',
'print'             => 'Paaki',
'edit'              => 'Fatu',
'create'            => 'Fakatupu',
'editthispage'      => 'Fatuʻi e pēsí ni',
'delete'            => 'Tāmateʻi',
'deletethispage'    => 'Tāmateʻi he pēsí ni',
'undelete_short'    => 'Taʻetāmateʻi ʻa e fatu ʻe $1',
'protect'           => 'Maluʻi',
'protect_change'    => 'liliu',
'protectthispage'   => 'Maluʻi e pēsí ni',
'unprotect'         => 'taʻemaluʻi',
'unprotectthispage' => 'ʻE taʻemaluʻi he pēsí ni',
'newpage'           => 'Peesi foʻou',
'talkpage'          => 'Aleaʻi he pēsí ni',
'talkpagelinktext'  => 'Alea',
'specialpage'       => 'Peesi makehe',
'personaltools'     => 'Puha haʻate meʻangāue',
'postcomment'       => 'Fokotuʻu ha fakamatala',
'articlepage'       => 'Vakai ki he peesi kakano',
'talk'              => 'Alea',
'views'             => 'Ngaahi vakai',
'toolbox'           => 'Puha meʻangāue',
'userpage'          => 'Vakai ki he peesi ʻo e ʻetita',
'imagepage'         => 'Vakai ki he peesi ʻo e ʻata',
'templatepage'      => 'Vakai ki he peesi sīpinga',
'viewhelppage'      => 'Vakai ki he peesi fakatokoni',
'categorypage'      => 'Vakai ki he peesi faʻahinga',
'viewtalkpage'      => 'Vākai ki he alea',
'otherlanguages'    => 'ʻi he ngaahi lea kehe',
'redirectedfrom'    => '(Kuo leʻei mei $1)',
'redirectpagesub'   => 'Peesi leʻei',
'viewcount'         => 'Naʻe laua he pēsí ni tuʻo $1.',
'protectedpage'     => 'Peesi maluʻi',
'jumpto'            => 'Hopo ki he:',
'jumptonavigation'  => 'ʻai taumuʻa',
'jumptosearch'      => 'kumi',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Kau ki: {{SITENAME}}',
'aboutpage'            => 'Project:ʻo kau ki',
'currentevents'        => 'Ngaahi ongoongo',
'currentevents-url'    => 'Project:Ongoongo taka',
'disclaimers'          => 'Ngaahi fakaʻataʻatā',
'disclaimerpage'       => 'Project:Fakaʻataʻatā lūkufua',
'edithelp'             => 'Tokoni ki he fatu',
'mainpage'             => 'Peesi tali fiefia',
'mainpage-description' => 'Peesi tali fiefia',
'portal'               => 'Fale fakataha',
'portal-url'           => 'Project:Fale fakataha',

'badaccess'        => 'Halaʻi fakangofua',
'badaccess-group0' => 'ʻOku ʻikai ngofua kia te koe ʻo fai ʻa e ngāue naʻa ke eke ki ai.',
'badaccess-groups' => 'Ko e ngāue naʻa ke eke ki ai, ʻoku fakangatangata ki he kau ʻetita ʻi he taha ʻo e ngaahi kulupu $1 pē.',

'versionrequired'     => "ʻOku pau ko e paaki $1 ʻo e ''MediaWiki''",
'versionrequiredtext' => "ʻOku pau ʻoku ʻi ai e paaki $1 'o e ''Mediwiki'' ʻi he ngāueʻaki ʻo e pēsí ni. Vakai ki he [[Special:Version]].",

'ok'                      => 'Fai ā',
'youhavenewmessages'      => 'ʻOku ʻi ai haʻo $1 ($2).',
'newmessageslink'         => 'ngaahi tala foʻou',
'youhavenewmessagesmulti' => 'ʻOku ʻi ai haʻo tala foʻou ʻi $1',
'editsection'             => 'fatuʻi vahe',
'editold'                 => 'fatu',
'editlink'                => 'fatu',
'viewsourcelink'          => 'vakai ki he tupunga',
'editsectionhint'         => 'Fatuʻi vahe: $1',
'toc'                     => 'Kakano',
'showtoc'                 => 'ʻasi mai',
'hidetoc'                 => 'toi',
'thisisdeleted'           => 'Vakai pe fakafoki: $1?',
'viewdeleted'             => 'Vakai ke he $1?',
'restorelink'             => 'ko e fatu ʻosi tāmateʻi ʻe $1',
'feedlinks'               => 'Fafanga:',
'feed-invalid'            => 'Ko e falenga fafanga ʻoku taʻeʻaonga.',
'site-atom-feed'          => "$1 Lave ''Atom''",
'page-rss-feed'           => "\"\$1\" lave ''RSS''",
'page-atom-feed'          => "\"\$1\" lave ''Atom''",
'red-link-title'          => '$1 (ʻoku ʻikai moʻui ʻa e pēsí)',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Kupu',
'nstab-user'      => 'Peesi ʻo e ʻetita',
'nstab-special'   => 'Peesi makehe',
'nstab-image'     => 'Faitā',
'nstab-mediawiki' => 'Tala',
'nstab-template'  => 'Sīpinga',
'nstab-help'      => 'Tokoni',
'nstab-category'  => 'Faʻahinga',

# Main script and global functions
'nosuchaction'      => 'Hala ha ngāue pehē',
'nosuchspecialpage' => 'Hala ha peesi makehe pehē',

# General errors
'error'                => 'Halaʻi',
'databaseerror'        => 'Halaʻi tānekingaʻilo',
'laggedslavemode'      => 'Tokanga: Mahalo pē ʻoku ʻikai ha toki fakafoʻou ʻi loto peesi.',
'readonly'             => 'ʻOku lokaʻi ʻa e tānekingaʻilo',
'readonlytext'         => 'ʻOku lokaʻi ʻa e tānekingaʻilo he taimí ni (ʻoku ikai te ke lava fatu) maʻa e monomono fakatānekingaʻilo tuʻumaʻu. ʻOsi ia ʻe foki ia ki hono faʻafai.

Ko e pule, naʻe lokaʻi ia, ʻoku pehē: $1',
'readonly_lag'         => 'Naʻe lokaʻi fakamīsini ʻa e tānekingaʻiló ni lolotonga he fetulitlui hake ʻo e tauhia pōpula mo e tauhia pule',
'internalerror'        => 'Hala fakalototānekingaʻilo',
'filecopyerror'        => 'Naʻe ʻikai lava ʻo hiki tatau ʻa e faile "$1" ki he "$2".',
'filerenameerror'      => 'Naʻe ʻikai lava liliu hingoa ʻo e faile "$1" ki he "$2".',
'filedeleteerror'      => 'Naʻe ʻikai lava ʻo tāmateʻi ʻa e faile "$1".',
'filenotfound'         => 'Naʻe ʻikai maʻu ko e faile "$1".',
'unexpected'           => 'Mahuʻinga taʻeʻamanekina: "$1"="$2".',
'badarticleerror'      => 'ʻOku ikai lava ke ke fai ʻa e ngāuē ni ki he peesi koʻeni.',
'cannotdelete'         => 'Naʻe ʻikai lava tāmateʻi ʻa e peesi pe faile naʻe tala. Mahalo pē kuo tāmateʻi ʻuluaki ia ʻe he ʻetita kehe.',
'badtitle'             => 'Hingoa ʻikai sai',
'badtitletext'         => "Naʻe taʻeʻaonga ʻa e hingoa ʻo e peesi naʻa ke fili, pe naʻe ʻi ai ha fehokotaki māhehei fakalea kehe pe fehokotaki māhehei faka''wiki'' kehe. Mahalo pe ʻoku ʻi loto ha ʻū mataʻitohi ʻoku ʻikai lava ngāueʻaki ʻi ha hingoa.",
'perfcached'           => 'ʻOku fafaʻo ʻa e meʻaʻilo ʻi lalo, pea mahalo pē ʻoku ʻikai fakafoʻoua. A maximum of {{PLURAL:$1|one result is|$1 results are}} available in the cache.',
'perfcachedts'         => 'ʻOku fafaʻo ʻa e meʻaʻilo ʻi lalo, naʻe fakaonopooni fakamuimui ia $1. A maximum of {{PLURAL:$4|one result is|$4 results are}} available in the cache.',
'wrong_wfQuery_params' => "Ngaahi mahuʻinga ʻikai totonu ki he ''wfQuery()''<br />
Lakanga: $1<br />
Eke: $2",
'viewsource'           => 'Vakai ki he tupunga',
'protectedinterface'   => 'Ko e peesi ʻeni ʻoku fakaai ia ʻa e potutohi maʻa e founga fakakomipiuta, ʻoku maluʻi ia ʻo taʻofi leakovi.',
'editinginterface'     => "'''Fakatokanga''' ʻOku ke fatu ʻi he peesi ʻoku ne ngāueʻaki ki he potutohi ʻo e founga fakakomipiuta. Ko ia ʻene ʻasi mai maʻa e kau ʻetita kotoa ʻe hūkitonu ai ʻa e ngaahi liliu ʻo e pēsí.",
'sqlhidden'            => '(ʻOku toi ʻa e fehuʻi SQL)',
'namespaceprotected'   => "ʻOku ʻikai ngofua ke ke fatu ʻa e ngaahi kupu ʻi he vā hingoa '''$1'''.",

# Login and logout pages
'logouttext'                 => "'''Kuo ʻalu mamaʻo koe he taimí ni.'''

E lava te ke hoko atu ʻo ngāueʻaki he {{SITENAME}} tatau mo e ʻetita taʻehingoa, pe te ke kau-ki-ai mo e hingoa tatau pe hingoa kehe.
Tokanga, mahalo pē ʻe ʻi ai ha ngaahi peesi ʻoku ʻasi ko koe kei kau-ki-ai aʻu ki he taimi te ke fakaʻatā ʻa e fafaʻo fakapalausa.",
'welcomecreation'            => '== Tali fiefia, $1! ==

Kuo fakatupu hoʻo tohi kau-ki-ai. ʻOua ʻe ngalo ke liliu hoʻo faʻiteliha {{SITENAME}}.',
'yourname'                   => 'Hingoa ʻetita',
'yourpassword'               => 'Leatapu',
'yourpasswordagain'          => 'Toe ʻai leatapu',
'remembermypassword'         => 'Manatuʻi au (for a maximum of $1 {{PLURAL:$1|day|days}})',
'yourdomainname'             => 'ho ngāueʻanga',
'login'                      => 'Kau ki ai',
'nav-login-createaccount'    => 'Kau ki ai',
'loginprompt'                => 'ʻOku pau te ke fakamafeia ʻa e ngaahi foʻi keke kapau te ke fie kau-ki-ai ki he {{SITENAME}}.',
'userlogin'                  => 'Kau ki ai',
'logout'                     => 'ʻAlu mamaʻo',
'userlogout'                 => 'ʻAlu mamaʻo',
'notloggedin'                => 'ʻIkai kau-ki-ai',
'nologin'                    => "Teʻeki maʻu haʻo tohi-kau-ki-ai? '''$1'''.",
'nologinlink'                => 'Fakatupu hoʻo tohi-kau-ki-ai',
'createaccount'              => 'Fakatupu ʻa e tohi-kau-ki-ai',
'gotaccount'                 => "ʻOsi maʻu ʻa e tohi-kau-ki-ai? '''$1'''.",
'gotaccountlink'             => 'Kau ki ai',
'createaccountmail'          => 'ʻi he tohila',
'badretype'                  => 'ʻOku kehe hoʻo ongo leatapu.',
'loginerror'                 => 'Halaʻi kau-ki-ai',
'nocookiesnew'               => 'Kuo fakatupu hoʻo tohi-kau-ki-ai, kae teʻeki ke kau-ki-ai. ʻOku ngāueʻaki mo e foʻi keke ʻe he {{SITENAME}} ʻi he kau-ki-ai ʻo e kau ʻetita. Naʻa ke fakataʻeʻaongaki ʻa e ngaahi foʻi keke. ʻE fakamafeia kinautolu pea te ke kau-ki-ai mo ho hingoa tenetene foʻou mo hono tapulea.',
'nocookieslogin'             => 'ʻOku ngāueʻaki mo e foʻi keke ʻe he {{SITENAME}} ʻi he kau-ki-ai ʻo e kau ʻetita. Naʻa ke fakataʻeʻaongaki ʻa e ngaahi foʻi keke. ʻE fakamafeia kinautolu pea te ke toe feinga.',
'noname'                     => 'Naʻe ʻikai te ke ʻoatu hao hingoa ʻetita ʻoku totonu.',
'loginsuccesstitle'          => 'Kuo ola ʻa e kau-ki-ai',
'loginsuccess'               => "'''ʻOku ke kau-ki-ai he taimí ni ki he {{SITENAME}} hangē \"\$1\".'''",
'nosuchuser'                 => 'ʻOku ʻikai ʻi ai ha ʻetita mo hono hingoa "$1". Sivi hoʻo sipela pe [[Special:UserLogin/signup|fakatupu haʻo kau-ki-ai foʻou]].',
'nosuchusershort'            => 'ʻOku ʻikai ʻi ai ha ʻetita mo hono hingoa "$1". Sivi hoʻo sipela.',
'nouserspecified'            => 'ʻOku pau te ke ʻoatu ha hingoa ʻo e ʻetita.',
'wrongpassword'              => 'ʻOku ʻikai totonu ʻa e leatapu, kātaki ʻe toki feinga.',
'wrongpasswordempty'         => 'Naʻe maha ʻa e tapulea, kātaki ʻe toki feinga.',
'passwordtooshort'           => 'ʻOku fuʻu nounou hoʻo leatapu. ʻE pau ʻoku ʻi loto ko e mataʻitohi ʻe $1 pe lahi ange.',
'mailmypassword'             => 'Tohila mai ʻa e leatapu foʻou',
'passwordremindertitle'      => 'Ko e fakamanatu ki he leatapu mei he {{SITENAME}}',
'passwordremindertext'       => 'Ko e tokotaha, mahalo pe ko koe mei he tuʻasila IP $1, naʻe kole ia ke ʻavea ha leatapu foʻou maʻa e {{SITENAME}} ($4). Ko e leatapu maʻa e ʻetita "$2", ʻoku "$3" he taimí ni. ʻOku ke pau te ke kau-ki-ai pea te ke liliu hoʻo leatapu. Ko e leatapu fakataimi ʻe mate ia ʻi he ʻaho ʻe $5.

Kapau naʻe kole ia ʻe he tokotaha kehe, pea ʻosi hoʻo manatuʻi ʻo e leatapu motuʻa mo ʻoku ʻikai te ke kei fieliliu ia, ʻe sai te ke taʻetokaʻi ʻa e fakamatalá ni pea ngāueʻaki ai pe hoʻo leatapu motuʻa.',
'noemail'                    => 'ʻOku ʻikai ʻiloa ha tuʻasila tohila maʻa e ʻetita "$1".',
'passwordsent'               => 'ʻOsi ʻave ʻa e leatapu foʻou ki he tohila kuo lēsisita maʻa "$1". Kātaki ʻe toe kau-ki-ai ʻosi maʻu ia.',
'eauthentsent'               => 'Kuo ʻave ʻa e tohila fakomoʻoniʻi ki he tuʻasila tohila naʻe fokotuʻu. ʻE pau te ke muitala ʻa e tohilá ni pea fakamoʻoniʻi ʻe koe ko e tuʻasila ē ʻoku moʻoni ko e tuʻasila ʻaʻau, ki muʻa ʻe ʻi ai ha tohila ʻe taha ʻe ʻave ia ki he tuʻasila ko ē.',
'mailerror'                  => 'Hala mei he tohila, ʻene ʻave ia: $1',
'acct_creation_throttle_hit' => 'Fakamolemole, kuo ʻosi hoʻo fakatupu ʻa e tohi kau-ki-ai ʻe $1 mei he tuʻasila IP ʻeni. ʻOku ʻikai te ke lava tānaki ki ai he ʻahó ni.',
'emailauthenticated'         => 'Kuo fakamoʻoniʻi ho tuʻasila tohila ʻi he $2, $3.',
'emailnotauthenticated'      => "ʻOku '''teʻeki fakamoʻoniʻi''' hoʻo tuʻasila tohila. ʻE ʻikai ʻaupito ʻave ha tohila ki ai.",
'noemailprefs'               => 'Tala ange ha tuʻasila tohila, ke sai ʻa e ngaahi meʻa ē.',
'emailconfirmlink'           => 'Fakamoʻoniʻi ho tuʻasila tohila',
'invalidemailaddress'        => 'ʻOku ʻikai tali ʻa e tohila ʻeni, koeʻuhi ʻoku hā taʻeʻaonga ia. Kātaki fokotuʻu ha tohila totonu pe fakaʻataaʻi ʻa e malaʻé na.',
'accountcreated'             => 'Kuo fakatupu ʻa e tohi-kau-ki-ai',
'accountcreatedtext'         => 'Kuo fakatupu ʻa e tohi kau-ki-ai maʻa $1.',
'loginlanguagelabel'         => 'Lea: $1',

# Change password dialog
'oldpassword' => 'Ko e leatapu motuʻa:',
'newpassword' => 'Ko e leatapu foʻou:',
'retypenew'   => 'Toe ʻai leatapu foʻou:',

# Edit page toolbar
'bold_sample'     => 'Tohi sinolahi',
'bold_tip'        => 'Tohi sinolahi',
'italic_sample'   => 'Mataʻitohi mahei',
'italic_tip'      => 'Mataʻitohi mahei',
'link_sample'     => 'Hingoa ʻo e fehokotaki',
'link_tip'        => 'Fehokotaki fakalotovā',
'extlink_sample'  => 'http://www.example.com Hingoa fakafehokotaki',
'extlink_tip'     => 'Fehokotaki ki tuʻa (manatuʻi ko e fakapipikimuʻa — http://)',
'headline_sample' => 'Mataʻitohi tuʻumuʻa',
'headline_tip'    => 'Tuʻumuʻa fakatuʻunga hono 2',
'nowiki_sample'   => 'Hulumaki ʻa e ʻū mataʻitohi taʻengaohi ʻi heni',
'nowiki_tip'      => "taʻetokaʻi ngaohi ''wiki''",
'sig_tip'         => 'Ko e fakamoʻoniʻi ʻaʻau mo hono taimi',

# Edit pages
'summary'                 => 'Fakanounou:',
'subject'                 => 'Tuʻunga lea:',
'minoredit'               => 'Ko e fatu siʻi pē ia',
'watchthis'               => 'Leʻo he pēsí ni',
'savearticle'             => 'Haofaki e pēsí',
'preview'                 => 'Vakai pē',
'showpreview'             => 'Vakai pē',
'showlivepreview'         => 'Vakai pē fakamoʻui',
'showdiff'                => 'ʻAsi mai ha ngaahi liliu',
'anoneditwarning'         => 'ʻOku ʻikai te ke kau-ki-ai. ʻE tohi ho tuʻasila IP ʻi he hisitōlia ʻo e fatu ʻa e pēsí ni.',
'missingsummary'          => "'''Fakamanatu''': Naʻe ʻikai te ke fakaai ha fakanounou. Kapau te ke toe lomi Haofaki, ʻe haofakiʻi hoʻo fatu taʻefakanounou.",
'missingcommenttext'      => 'Kātaki tuku pē ʻi lalo ʻa e fakamatala',
'blockedtitle'            => 'ʻOku taʻofia ʻa e ʻetitá',
'whitelistedittext'       => 'ʻOku pau te ke $1 kapau te ke fiefatu ʻa e ngaahi kupu.',
'confirmedittext'         => 'ʻOku pau te ke fakamoʻoniʻi ho tuʻasila tohila ʻi muʻa hoʻo fatu kupu. Kātaki ʻe fakamoʻoniʻi ia ngāueʻaki hoʻo [[Special:Preferences|faʻiteliha]] fakaʻetita.',
'loginreqtitle'           => 'ʻOku pau te ke kau ki ai',
'loginreqlink'            => 'kau ki ai',
'loginreqpagetext'        => 'ʻOku pau ke $1 kapau te ke fievakai ki he ngaahi peesi ʻe taha.',
'accmailtitle'            => 'ʻOsi ʻave ʻa e leatapu',
'accmailtext'             => "ʻOsi ʻave ʻa e leatapu maʻa [[User talk:$1|$1]] ki he $2. Te ke lava liliu ia ʻi he ''[[Special:ChangePassword|peesi liliu leatapu]]''.",
'newarticle'              => '(Foʻou)',
'newarticletext'          => "Naʻa ke muimui ha fehokotaki ki he peesi ʻoku teʻeki fakatupu. Kapau te ke fiefakatupi he pēsí ni, kamata hoʻo tohi ʻi he puha ʻi lalo. (Vakai ki he [[{{MediaWiki:Helppage}}|tokoni]] mo hano ongoongo lahi ange.) Kapau ʻoku hala pē heni, lomiʻi pē he meʻa-lolomi 'ki mui' ʻo ho palausa.",
'anontalkpagetext'        => "----''Ko e peesi ʻeni ko e peesi alea ia maʻa e ʻetita taʻehingoa teʻeki ʻene fakatupu ʻo e tohi kau-ki-ai pe ʻoku ʻikai ngāueʻaki mo ia. Ko ia ai ʻoku fakapapauʻi ia ʻe he tuʻasila IP fakafika pē. Ka ʻe lava ʻoku vahevahe ʻa e tuʻasila IP pehē ʻe he kau ʻetita tokolahi. Kapau ko koe ko e ʻetita taʻehingoa, ʻoku ke tui ko e ngaahi fakamatala ʻi heni ʻoku ʻikai maʻau, mahalo pē ʻoku sai ange ke ke [[Special:UserLogin|fai ha tohi kau-ki-ai, pe kau-ki-ai]] he taimí ni pea fakaʻehiʻehi ha ngaahi meʻafihi ē ʻi he kahaʻu.''",
'noarticletext'           => 'Ko e pēsi ni, ʻoku ʻikai haʻane tohi ʻi ai he taimi ni. ʻE lava koe ʻo [[Special:Search/{{PAGENAME}}|kumi ki heʻene hingoa]] ʻi ha ngaahi peesi ʻe taha, pe [{{fullurl:{{FULLPAGENAME}}|action=edit}} ʻetita ʻi ai.]',
'clearyourcache'          => "'''Tokanga''', ʻosi he haofaki e peesi, mahalo pē ʻoku pau te ke fakaʻatā ʻa e fafaʻo ʻo ho palausa, naʻa ʻikai te ke sio ʻa e paaki foʻou.",
'updated'                 => '(Fakafoʻou)',
'note'                    => "'''Tohi nounou:'''",
'previewnote'             => "'''Ko e vakai pē ia, teʻeki haofakiʻi ʻa e ngaahi liliu!'''",
'session_fail_preview'    => "'''Kātaki, naʻe ʻikai fai hoʻo fatu ko e ʻuhinga ia ai naʻe mole ʻa e meʻaʻilo. Kātaki toki feinga. Kapau e toe hala, mahalo pē te ke ʻalu mamaʻo pea te ke toki kau ki ai.'''",
'editing'                 => 'ʻOku fatuʻi $1',
'editingsection'          => 'ʻOku fatuʻi $1 (vahe)',
'editingcomment'          => 'ʻOku fatuʻi $1 (fakamatala foʻou)',
'editconflict'            => 'Fepaki fatu: $1',
'explainconflict'         => "Naʻe liliu ʻa e pēsí ni ʻe he ʻetita ʻe taha lolotonga he taimi kuo ke kamata hoʻo fatu.
Ko e konga ʻi olunga, ko e kupu ia he onopooni.
Ko e konga ʻi lalo, ko hoʻo ngaahi liliu ia.
ʻE pau te ke fakataha hoʻo liliu ʻi loto ʻo e kupu ʻoku tuʻu.
Ko e konga ʻi olunga, ko e '''konga pē ʻe taha''' ʻe haofaki ʻi he lomiʻi ʻo e meʻalolomi \"{{int:savearticle}}\".",
'yourtext'                => 'tohi ʻaʻau',
'storedversion'           => 'Ko e paaki kuo tuku',
'editingold'              => "'''FAKATOKANGA: ʻOku ke fatu ʻi he paaki fakaonoʻaho ʻo e pēsi. Kapau te ke haofaki ia, ʻe mole ʻa e ngaahi liliu kotoa talu mei ai.'''",
'yourdiff'                => 'Meʻa kehekehe',
'copyrightwarning'        => "Fakamolemole, manatuʻi ko e ngaahi foaki kotoa pē ki he {{SITENAME}} ʻoku nau moʻulaloa ki he \"\$2\" (vakai ki he \$1 maʻa ngaahi kiʻi meʻa). Kapau ʻoku ʻikai te ke loto ki ai, ʻikai te ke fiemaʻu ʻa e ngaahi liliu taʻeʻofa, ʻikai holi ki ha pulusi ʻi he feituʻu kotoa pe, ʻe sai ange ʻe ʻikai ke ke ʻetita heni.

ʻOku foki te ke palōmesi naʻa ke tohi ia ʻe koe, pe hiki ia mei he tohi tauʻatāina, '''ʻOku ʻikai ʻaupito te ke ʻoatu ha tohi ʻoku foʻi mafai ke pulusi maʻa e tokotaha.'''",
'readonlywarning'         => "'''TOKANGA. ʻOku lokaʻi ʻa e tānekingaʻilo maʻa e monomono, ko ia ai ʻe ikai te ke lava haʻofaki hoʻo fatu he taimí ni. Mahalo pē te ke fie haʻofaki, hiki pea piki, hoʻo fatu ʻi he faile, ki he kahaʻu.'''

Ko e ʻuhinga loka ko e $1 ia.",
'cascadeprotectedwarning' => "'''Tokanga:''' ʻOku lokaʻi ʻa e pēsí ni ki he fatu, (ʻoku lava pē ʻe he kau pule), koeʻuhi ʻoku kau ki he ngaahi peesi ʻasi ʻi lalo, ʻoku nau maluʻi mo e hohoko fakaivia ʻi he peesi ʻe $1:",
'templatesused'           => 'Ngaahi sīpinga ʻoku ngāueʻaki he kupú ni:',
'templatesusedpreview'    => 'Ngaahi sīpinga ʻoku ngāueʻaki he vakaí ni:',
'templatesusedsection'    => 'Ngaahi sīpinga ʻoku ngāueʻaki he kongá ni:',
'nocreatetitle'           => 'ʻOku fakangatangata ʻa e fakatupu ʻo e peesi.',
'nocreatetext'            => 'Naʻe fakangatangata ʻe he tuʻuʻangá ni ʻa e lava ke fakatupu ha peesi foʻou. ʻOku ke lava ke foki pea fatu ha peesi tuʻu, pe [[Special:UserLogin|kau-ki-ai, pe fakatupu ha tohi-kau-ki-ai]].',

# Account creation failure
'cantcreateaccounttitle' => 'ʻOku ʻikai lava fakatupu e tohi kau-ki-ai',

# History pages
'viewpagelogs'        => 'Vakai ki he ngaahi tohinoa ʻo e pēsí ni',
'nohistory'           => 'ʻOku ʻikai ʻi ai ha hisitōlia fatu maʻa e kupú ni.',
'currentrev'          => 'Paaki taka',
'revisionasof'        => 'Paaki he ko $1',
'revision-info'       => 'Paaki he ko $1 fai ʻe $2',
'previousrevision'    => '←Paaki motuʻa ange',
'nextrevision'        => 'Paaki foʻou ange→',
'currentrevisionlink' => 'Paaki taka',
'cur'                 => 'taka',
'next'                => 'hoko',
'last'                => 'fakamuimui',
'histlegend'          => 'Konga faikehekehe: fakaʻilongaʻi ʻa e ngaahi puha fakaletio ʻo e ngaahi paaki ʻo fakatatau pea lomiʻi.<br />
ʻAtungatala: (taka) = ngaahi lilu mo e paaki taka, (mui) = ngaahi liliu mo paaki naʻe fetongi, s = fatu siʻi.',
'histfirst'           => 'Fakamuʻa taha',
'histlast'            => 'Fakamuimui taha',

# Revision feed
'history-feed-title' => 'Hisitōlia ʻo e paaki',

# Revision deletion
'rev-deleted-comment'       => '(kuo toʻo ʻa e fakamatala)',
'rev-delundel'              => 'ʻasi/toi',
'revdelete-hide-comment'    => 'Toi he fakamatala maʻa e tohinoa',
'revdelete-hide-restricted' => 'ʻAi ʻa e ngaahi fakangatangatá ni maʻa e kau pule fakafounga mo e kau kotoa',
'revdelete-log'             => 'ʻUhinga',

# Merge log
'revertmerge' => 'Vete ʻa e fakataha',

# Diffs
'difference'              => '(Kehekehe he ongo paaki)',
'lineno'                  => 'Laini hono $1:',
'compareselectedversions' => 'Fakatatau ongo paaki fili',
'editundo'                => 'vete',
'diff-multi'              => '(Naʻe ʻikai ʻasi mai ʻa e paaki lotoloto ʻe $1).',

# Search results
'searchresults'             => 'kumi hono ʻātunga',
'searchresults-title'       => 'kumi "$1" hono ʻātunga',
'prevn'                     => '{{PLURAL:$1|$1}} ki muʻa',
'nextn'                     => '{{PLURAL:$1|$1}} hoko',
'viewprevnext'              => 'Vakai ki he ($1 {{int:pipe-separator}} $2) ($3).',
'search-suggest'            => 'Mahalo pē naʻa ke fiemaʻu: $1',
'search-interwiki-more'     => '(lahi ange)',
'search-mwsuggest-enabled'  => 'mo e fokotuʻu atu',
'search-mwsuggest-disabled' => 'taʻe fokotuʻu atu',
'showingresults'            => "ʻOku ʻasi ʻi lalo ʻa e ngaahi fua ʻoku kamata mo e #'''$2''' (aʻu ki he '''$1''').",
'showingresultsnum'         => "ʻOku ʻasi ʻi lalo ha fua ʻe '''$3''', ʻoku kamata mo e #'''$2'''.",
'nonefound'                 => "Ko e ngaahi kumi naʻe ʻikai ke siaʻa. Mahalo pē te ke fiefeinga kumi ʻi he ngaahi vā hingoa kotoa (kupu, alea, sīpinga, mo e hā fua). Tānaki ''all:'' ʻi muʻa ʻo hoʻo fehuʻi.",
'powersearch'               => 'Kumi',
'powersearch-legend'        => 'Kumi lakasi',
'powersearch-redir'         => 'Hokohoko ʻo e ngaahi leʻei',

# Preferences page
'preferences'           => 'Faʻiteliha',
'mypreferences'         => 'faʻiteliha ʻaʻaku',
'prefsnologin'          => 'ʻOku ʻikai kau ki ai',
'changepassword'        => 'Liliu hoʻo leatapu',
'prefs-skin'            => 'Kili',
'skin-preview'          => 'Vakai pē',
'datedefault'           => 'ʻIkai ha faʻiteliha',
'prefs-datetime'        => 'ʻAho mo e taimi',
'prefs-personal'        => 'Fōtunga fakatafaʻaki',
'prefs-rc'              => 'Ngaahi toki liliu',
'prefs-watchlist'       => 'Hokohoko leʻo',
'prefs-watchlist-days'  => 'Ngaahi ʻaho hono lahi ʻoku ʻasi ʻi he hokohoko leʻo:',
'prefs-watchlist-edits' => 'Ngaahi fatu hono lahi ʻoku ʻasi ʻi he hokohoko leʻo fano:',
'prefs-misc'            => 'Kehekehe',
'saveprefs'             => 'Haofaki',
'resetprefs'            => 'Fakafoki',
'prefs-editing'         => 'ʻOku fatu',
'rows'                  => 'Ngaahi ʻotu:',
'columns'               => 'Vahaʻa laini:',
'searchresultshead'     => 'Kumi',
'recentchangescount'    => 'Ngaahi ʻuluʻitohi ʻoku ʻasi ʻi he toki liliu, hisitōlia peesi, mo e hokohoko:',
'savedprefs'            => 'Kuo haofaki hoʻo faʻiteliha.',
'timezonelegend'        => 'Feituʻu taimi',
'localtime'             => 'Taimi fakafeituʻu:',
'timezoneoffset'        => 'Ngaahi houa ʻo e faikehekehe:',
'servertime'            => 'Taimi ʻo e tauhia:',
'timezoneregion-africa' => 'ʻAfelika',
'allowemail'            => 'Fakamafeiaʻi ʻa e tohila mei he kau ʻetita ʻe taha',
'defaultns'             => 'Kumi ʻi he vā hingoa fakatuʻunga:',
'default'               => 'tuʻunga',
'prefs-files'           => 'Ngaahi faile',
'youremail'             => 'Tohila:',
'username'              => 'Ko e ʻetita hono hingoa:',
'uid'                   => 'hono fika:',
'yourrealname'          => 'Hingoa moʻoni:',
'yourlanguage'          => 'Lea:',
'yourvariant'           => 'Faikeheʻi',
'yournick'              => 'Hingoa tenetene:',
'badsig'                => 'Ko e fakamoʻoni ʻota ʻoku taʻeʻaonga; siviʻi ngaahi tikite HTML.',
'email'                 => 'Tohila',
'prefs-help-email'      => 'Tohila (tohi-ʻuhila, e-mail) fakafaʻiteliha: ʻE fakamafeiaʻi ʻa e kau ʻetita ʻo lave kia te koe, ngāueʻaki hoʻo peesi pe peesi-alea, taʻe ʻi ai haʻanau ʻilo pe ko hai koe.',

# Groups
'group'            => 'Pupunga:',
'group-bot'        => 'Ngaahi fatu fakamīsini',
'group-sysop'      => 'Kau pule fakafounga',
'group-bureaucrat' => 'Kau pulelahi',
'group-all'        => '(kotoa)',

'group-bot-member'        => 'Fakamīsini',
'group-sysop-member'      => 'Pule fakafounga',
'group-bureaucrat-member' => 'Pulelahi',

# User rights log
'rightslog'     => 'Tohinoa ʻo e kau ʻetita honau maʻu mafai',
'rightslogtext' => 'Ko e tohinoa ʻeni ʻo e ngaah liliu ʻo e kau ʻetita ʻenau maʻu mafai',
'rightsnone'    => '(hala)',

# Recent changes
'recentchanges'      => 'Ngaahi toki liliu',
'recentchangestext'  => 'Fakatotolo ʻa e ngaahi toki liliu ki he wiki ʻi he pēsí ni.',
'rcnote'             => 'ʻOku ʻasi ʻi lalo ʻa e liliu fakamuimui ʻe <strong>$1</strong> lolotonga ʻa e ʻaho fakamuimui ʻe <strong>$2</strong> mei he taimi: $4, $5',
'rcnotefrom'         => "ʻOku ʻasi ʻi lalo ʻa e liliu talu mei '''$2''' (aʻu ki he '''$1''').",
'rclistfrom'         => 'ʻAsi mai ha ngaahi liliu foʻou ʻo kamata mei he $1',
'rcshowhideminor'    => '$1 fatu siʻi',
'rcshowhidebots'     => '$1 fatu fakamīsini',
'rcshowhideliu'      => '$1 kau ʻetita ʻoku kau-ki-ai',
'rcshowhideanons'    => '$1 kau ʻetita taʻehingoa',
'rcshowhidemine'     => '$1 fatu ʻaʻaku',
'rclinks'            => 'ʻAsi mai ha liliu ʻe $1 lolotonga ha ʻaho ʻe $2 fakamuimui<br />$3',
'diff'               => 'kehe',
'hist'               => 'hisi',
'hide'               => 'Toi',
'show'               => 'ʻAsi mai',
'minoreditletter'    => 's',
'newpageletter'      => 'F',
'boteditletter'      => 'm',
'rc_categories'      => 'Fakangatangata ki he faʻahinga (vaheʻi he "|")',
'rc_categories_any'  => 'Faʻahinga noa pē',
'rc-enhanced-expand' => "ʻAsi ngaahi ʻeu (fiemaʻu ʻa e ''Javascript'')",
'rc-enhanced-hide'   => 'Toi ngaahi ʻeu',

# Recent changes linked
'recentchangeslinked'         => 'Ngaahi liliu fekauʻaki',
'recentchangeslinked-feed'    => 'Ngaahi liliu fekauʻaki',
'recentchangeslinked-toolbox' => 'Ngaahi liliu fekauʻaki',

# Upload
'upload'                      => 'Hiki hake ʻa e faile',
'uploadbtn'                   => 'Hiki hake',
'reuploaddesc'                => 'Foki ki he foomu hiki',
'uploadnologin'               => 'Teʻeki kau ki ai',
'uploadnologintext'           => 'ʻOku pau ke [[Special:UserLogin|kau-ki-ai]] kapau te ke fiehiki hake ha faile.',
'upload_directory_read_only'  => 'ʻOku ʻikai lava ʻo tohi ʻa e takafi ($1) ʻe he tauhia matamatakupenga.',
'uploaderror'                 => 'Halaʻi hiki hake',
'uploadlog'                   => 'tohinoa ʻo e ngaahi hiki hake',
'uploadlogpage'               => 'Tohinoa ʻo e ngaahi hiki hake',
'uploadlogpagetext'           => 'ʻOku ʻasi ʻi lalo ha hokohoko ʻo e ngaahi faile ʻenau hiki hake fakamuimui.',
'filename'                    => 'Ko e faile hono hingoa',
'filedesc'                    => 'Fakanounou',
'fileuploadsummary'           => 'Fakanounou:',
'filesource'                  => 'Tupunga:',
'uploadedfiles'               => 'Ngaahi faile ʻosi hiki hake',
'ignorewarning'               => 'Taʻetokaʻi fakatokanga pea haʻofakiʻi ʻa e faile',
'ignorewarnings'              => 'Taʻetokaʻi ngaahi fakatokanga',
'badfilename'                 => 'Naʻe liliu ko e hingoa ʻo e faile ki he "$1".',
'largefileserver'             => 'ʻOku fuʻu lahi ange ʻa e failé ni ʻi he tauhia hono ʻinasi.',
'emptyfile'                   => 'ʻOku ngalingali maha ʻa e faile naʻa ke hiki hake ai. Mahalo pē naʻa ke fakasipelahalaʻi ki he hingoa. Kātaki vakai ke ke pau te ke fiehiki ʻa e failé ni.',
'fileexists'                  => "ʻOku toka ʻi ai ha peesi mo e hingoa ē; fakamolemole fakamoʻoniʻi ki he '''<tt>[[:$1]]</tt>''' kapau ʻoku ʻikai te ke pau ʻo te ke fieliliu ia.
[[$1|thumb]]",
'fileexists-forbidden'        => 'ʻOku toka ʻi ai ha peesi mo e hingoa ē, pea ʻe ʻikai lava liliu; fakamolemole ʻe foki pea hiki hake ʻa e failé ni mo e ha hingoa foʻou. [[File:$1|thumb|center|$1]]',
'fileexists-shared-forbidden' => 'ʻOku toka ʻi ai ha peesi mo e hingoa ē ʻi he kalasi vahevahe; fakamolemole ʻe foki pea hiki hake ʻa e failé ni mo e ha hingoa foʻou. [[File:$1|thumb|center|$1]]',
'uploadwarning'               => 'Tokanga hiki hake',
'savefile'                    => 'Haofaki faitaá ni',
'uploadedimage'               => '"[[$1]]" ʻosi hiki hake',
'uploaddisabled'              => 'ʻOku fakataʻeʻaongaʻi ʻa e ngaahi hiki hake',
'uploaddisabledtext'          => 'ʻOku fakataʻeʻaongaʻi ha ngaahi hiki hake ʻi heni.',
'uploadvirus'                 => 'ʻOku ʻi ai ha vailasi ʻi he failé ni! ʻŪ kiʻi meʻa: $1',
'sourcefilename'              => 'Hingoa ʻo e faile tupunga:',
'destfilename'                => 'Hingoa ʻo e faile ʻe ʻalu ki ai:',
'watchthisupload'             => 'Leʻo he pēsí ni',
'filewasdeleted'              => 'Kuo hiki hake ʻa e faile mo e hingoa ʻeni pea naʻe tāmateʻi ia. Kuo pau te ke vakai ki he $1 ʻi muʻa haʻo feinga ʻo toe hiki hake ia.',
'upload-success-subj'         => 'Kuo ola ʻa e hiki hake',

'license'        => 'Laiseni:',
'license-header' => 'Laiseni:',
'nolicense'      => 'ʻIkai fili ha taha',

# Special:ListFiles
'listfiles_search_for'  => 'Kumi ki he hingoa ʻo e faitā:',
'imgfile'               => 'faile',
'listfiles'             => 'Hokohoko faitā',
'listfiles_date'        => 'ʻAho',
'listfiles_name'        => 'Hingoa',
'listfiles_user'        => 'ʻEtita',
'listfiles_size'        => 'Hono lahi (ʻū valu)',
'listfiles_description' => 'Fakamahino',

# File description page
'file-anchor-link'          => 'Faitā',
'filehist-datetime'         => 'ʻAho/Taimi',
'filehist-user'             => 'Ko e ʻetita',
'imagelinks'                => 'Ngaahi fehokotaki',
'linkstoimage'              => 'ʻOku fehokotaki ʻa e peesi ʻe $1 ki he failé ni:',
'nolinkstoimage'            => 'ʻOku ʻikai ha ngaahi peesi fehokotaki ki he faitaá ni.',
'uploadnewversion-linktext' => 'Hiki hake ʻa e paaki foʻou ʻo e failé ni.',

# File reversion
'filerevert'                => 'Toe foki $1 ki hono tuʻunga muʻa',
'filerevert-legend'         => 'Toe foki ʻa e faile ki hono tuʻunga muʻa',
'filerevert-intro'          => "ʻOku ke toe foki ʻa e '''[[Media:$1|$1]]''' ki hono tuʻunga muʻa, paaki $4 ʻo e $2 $3.",
'filerevert-comment'        => 'Fakamatala:',
'filerevert-defaultcomment' => 'Kuo toe foki $1 ki hono tuʻunga muʻa ʻo e $2',
'filerevert-submit'         => 'Toe foki ki hono tuʻunga muʻa',
'filerevert-success'        => "Kuo toe foki ʻa e '''[[Media:$1|$1]]''' ki hono tuʻunga muʻa, paaki $4 ʻo e $2 $3.",

# MIME search
'mimesearch' => 'Kumi fakaMIME',
'mimetype'   => 'Faʻahinga MIME:',
'download'   => 'hiki hifo',

# Unwatched pages
'unwatchedpages' => 'Peesi taʻeleʻo',

# List redirects
'listredirects' => 'Hokohoko ngaahi leʻei',

# Unused templates
'unusedtemplates'     => 'Sīpinga ʻoku ʻikai ngāueʻaki',
'unusedtemplatestext' => "ʻOku ʻasi heni ʻa e kupu kotoa ʻi he vā-hingoa ''{{ns:template}}'', ʻoku ʻikai ngāueʻaki ʻi he peesi ʻe taha. Manatuʻi te ke sivi ʻoku ʻi ai ha ngaahi fehokotaki kehe ki hē ki muʻa ʻi honau tāmateʻi.",
'unusedtemplateswlh'  => 'ngaahi fehokotaki kehe',

# Random page
'randompage' => 'Kupu noa pē',

# Random redirect
'randomredirect' => 'Leʻei noa pē',

# Statistics
'statistics'              => 'Sitesitesika',
'statistics-header-users' => 'Sitesitesika ʻo e ʻetita',
'statistics-mostpopular'  => 'Ko e ngaahi peesi naʻe vakai ki ai lahi taha',

'disambiguations'      => 'Peesi fakaʻuhingakehe',
'disambiguationspage'  => 'Template:Fakaʻuhingakehe',
'disambiguations-text' => "ʻOku ʻi ai haʻanau fehokotaki ki ha '''Peesi fakaʻuhingakehe''' maʻa e ngaahi kupu ʻoku ʻasi ʻi lalo. ʻE taau ʻo ʻenau fehokotaki ki he kupu totonu. ʻOku kau ʻa e kupu ki he peesi fakaʻuhingakehe kapau ʻoku ngāueʻaki ha sīpinga ʻoku ʻasi ʻi he  [[MediaWiki:Disambiguationspage]].",

'doubleredirects'     => 'Ngaahi leʻeleʻei',
'doubleredirectstext' => 'ʻOku ʻasi ʻi he ʻotu kotoa pē ha ongo fehokotaki ki he leʻei, mo e leʻeleʻei, mo e kamataʻanga ʻo e leʻeleʻei, taimi ʻe niʻihi ko e peesi totonu ia, ʻoku taau ʻe tuhu ki ai ʻe he leʻei.',

'brokenredirects'     => 'Ngaahi leʻei maumau',
'brokenredirectstext' => 'ʻOku leʻei ʻa e ngaahi fehokotakí ni ki he peesi taʻetuʻu:',

'withoutinterwiki'         => 'Ngaahi kupu taʻefehokotaki fakalea',
'withoutinterwiki-summary' => 'Ko e ngaahi peesi ʻoku ʻasi ʻi lalo ʻoku ʻikai ʻi ai haʻanau fehokotaki fakalea:',

'fewestrevisions' => 'Kupu mo e ngaahi paaki siʻi taha',

# Miscellaneous special pages
'nbytes'                  => 'ʻū valu ʻe $1',
'ncategories'             => 'Faʻahinga ʻe $1',
'nlinks'                  => 'fehokotaki ʻe $1',
'nrevisions'              => 'Paaki ʻe $1',
'specialpage-empty'       => 'ʻOku maha ʻa e pēsí ni.',
'lonelypages'             => 'Peesi fakapaea',
'uncategorizedpages'      => 'Peesi taʻefaʻahingaʻi',
'uncategorizedcategories' => 'Faʻahinga taʻefaʻahingaʻi',
'uncategorizedimages'     => 'Faitā taʻefaʻahingaʻi',
'uncategorizedtemplates'  => 'Sīpinga taʻefaʻahingaʻi',
'unusedcategories'        => 'Faʻahinga taʻengāueʻaki',
'unusedimages'            => 'Faitā taʻengāueʻaki',
'popularpages'            => 'Peesi manakoa',
'wantedcategories'        => 'Faʻahinga fiemaʻu',
'wantedpages'             => 'Kupu fiemaʻu',
'wantedfiles'             => 'Faile fiemaʻu',
'wantedtemplates'         => 'Sīpinga fiemaʻu',
'mostlinked'              => 'Peesi mo e ngaahi fehokotaki ki ai lahi taha',
'mostlinkedcategories'    => 'Faʻahinga mo e ngaahi fehokotaki ki ai lahi taha',
'mostlinkedtemplates'     => 'Sīpinga mo e ngaahi fehokotaki ki ai lahi taha',
'mostcategories'          => 'Kupu mo e ngaahi faʻahinga lahi taha',
'mostimages'              => 'Faitā mo e ngaahi fehokotaki ki ai lahi taha',
'mostrevisions'           => 'Kupu mo e ngaahi paaki lahi taha',
'prefixindex'             => 'Hokohoko fakapipikimuʻa kotoa',
'shortpages'              => 'Peesi nonou',
'longpages'               => 'Peesi lōloa',
'deadendpages'            => 'Peesi ngata-mate',
'protectedpages'          => 'Peesi maluʻi',
'protectedtitles'         => 'Ngaahi ʻuluʻitohi maluʻi',
'listusers'               => 'Hokohoko kau-ki-ai',
'newpages'                => 'Peesi foʻou',
'newpages-username'       => 'Ko e ʻetita hono hingoa:',
'ancientpages'            => 'Peesi motuʻa taha',
'move'                    => 'ʻunu',
'movethispage'            => 'ʻUnu e pēsí ni',
'unusedimagestext'        => 'Kātaki, manatuʻi ʻoku lava ʻe ʻi ai ha ngaahi feituʻu fakamatamatakupenga mo honau fehokotaki ki heni, ko ia ai mahalo pē ʻoku moʻui ʻaupito ia, neongo ʻene hā ʻi he hokohoko ko ʻeni.',
'unusedcategoriestext'    => 'ʻOku ʻi ai ha ngaahi faʻahinga ʻoku ʻikai ngāueʻaki ʻi ha kupu ʻe taha pe faʻahinga ʻe taha.',
'pager-newer-n'           => 'kupu foʻou ange ʻe $1',
'pager-older-n'           => 'kupu motuʻa ange ʻe $1',

# Book sources
'booksources'    => 'Ngaahi tupunga tohi',
'booksources-go' => 'Fai ā',

# Special:Log
'specialloguserlabel'  => 'ʻEtita:',
'speciallogtitlelabel' => 'Hingoa:',
'log'                  => 'Tohinoa',
'all-logs-page'        => 'Tohinoa kātoa',
'alllogstext'          => 'Fakaʻaliʻali fakakātoa ʻo e ngaahi tohinoa hiki hake, mo tāmateʻi, mo maluʻi, mo taʻofi, mo fakapule. ʻOku lava ke ke sivi ʻa e fakaʻaliʻalí ni ʻi he fili ʻo e falenga tohinoa pe hingoa ʻo e ʻetita pe peesi hūkitonu.',
'logempty'             => 'ʻOku maha ʻa e tohinoa.',

# Special:AllPages
'allpages'          => 'Peesi kotoa',
'alphaindexline'    => '$1 ki he $2',
'nextpage'          => 'Peesi hoko ($1)',
'prevpage'          => 'Peesi ki muʻa ($1)',
'allpagesfrom'      => 'ʻAsi mai ngaahi peesi ʻoku kamata he:',
'allarticles'       => 'Ngaahi kupu kātoa',
'allinnamespace'    => 'Peesi kotoa ($1 vā hingoa)',
'allnotinnamespace' => 'Ngaahi peesi kotoa, ʻoku ʻikai ʻi vā hingoa $1',
'allpagesprev'      => 'Ki muʻa',
'allpagesnext'      => 'Hoko',
'allpagessubmit'    => 'Fai ā',
'allpagesprefix'    => 'ʻAsi mai ngaahi peesi mo ʻenau fakapipikimuʻa:',
'allpagesbadtitle'  => "Naʻe taʻeʻaonga ʻa e hingoa ʻo e peesi naʻa ke fili, pe naʻe ʻi ai ha fakapipikimuʻa  fakalea kehe pe ha fakapipikimuʻa faka''wiki'' kehe. Mahalo pe ʻoku ʻi loto ha ʻū mataʻitohi ʻoku ʻikai lava ngāueʻaki ʻi ha hingoa.",

# Special:Categories
'categories'         => 'Faʻahinga',
'categoriespagetext' => 'ʻOku ʻi ai ha ngaahi faʻahinga pehē.
[[Special:UnusedCategories|Unused categories]] are not shown here.
Also see [[Special:WantedCategories|wanted categories]].',

# Special:DeletedContributions
'deletedcontributions'       => 'Ngaahi foaki ʻo ha ʻetita kuo tāmateʻi',
'deletedcontributions-title' => 'Ngaahi foaki ʻo ha ʻetita kuo tāmateʻi',

# Special:LinkSearch
'linksearch'       => 'Ngaahi fehokotaki fakamatamatakupenga',
'linksearch-line'  => 'Kuo fehokotaki ʻa e $1 mei he $2',
'linksearch-error' => 'ʻOku ngofua pē ke ʻasi ha ngaahi lauʻifano ʻi he kamataʻanga ʻo e tauhia hono hingoa.',

# Special:ListUsers
'listusersfrom'    => 'ʻAsi mai kau ʻetita mei he:',
'listusers-submit' => 'ʻAsi mai',

# Special:Log/newusers
'newuserlogpage'     => 'Tohinoa ʻo e fakatupu kau ʻetita',
'newuserlogpagetext' => 'Ko e tohinoa ʻeni ʻo e fakatupu kau ʻetita.',

# E-mail user
'mailnologin'     => 'ʻOku ʻikai ha tuʻasila ke tohila ki ai',
'emailuser'       => 'Tohila ki he ʻetitá ni',
'emailpage'       => 'Ko e ʻetita ʻene tohila',
'emailpagetext'   => 'Kapau kuo ʻoatu ʻe he ʻetita koʻeni haʻane tuʻasila tohila moʻoni ʻi heʻene faʻiteliha, ʻe ʻave ʻe he foomu ʻi lalo ha tala ʻe taha. Ko hoʻo tuʻasila tohila, naʻa ke ʻoatu ʻi hoʻo faʻiteliha, ʻe asi ia ʻi he feituʻu "mei he" ʻi he tohila ē, e fakamafeia kia te ia haʻane tali.',
'defemailsubject' => 'Ko e tohila ʻo e {{SITENAME}}',
'noemailtitle'    => 'Hala ha tuʻasila tohila',
'noemailtext'     => 'ʻOku ʻikai ʻoatu ʻa e tohila totonu ʻe he ʻetitá ni, pe ʻoku ʻikai te ne fiemaʻu ʻa e tohila mei he ʻetita ʻe taha.',
'emailfrom'       => 'Mei',
'emailto'         => 'Ki',
'emailsubject'    => 'Tuʻunga lea',
'emailmessage'    => 'Tala',
'emailsend'       => 'ʻAve ia',
'emailsent'       => 'Kuo ʻave ʻa e tohilá',
'emailsenttext'   => 'Kuo ʻave hoʻo tohila.',

# Watchlist
'watchlist'            => 'Hokohoko leʻo ʻaʻaku',
'mywatchlist'          => 'Hokohoko leʻo ʻaʻaku',
'nowatchlist'          => 'ʻOku ʻikai ha meʻa ʻi hoʻo hokohoko leʻo.',
'watchlistanontext'    => 'Kātaki, ʻe $1 kapau te ke fievakai pe fiefatu ha ngaahi meʻa ʻi hoʻo hokohoko leʻo.',
'watchnologin'         => 'Teʻeki kau ki ai',
'watchnologintext'     => 'ʻOku pau te ke [[Special:UserLogin|kau-ki-ai]] kapau te ke fieliliu hoʻo hokohoko leʻo.',
'addedwatchtext'       => 'Ko e peesi "[[:$1]]" naʻe tānaki ia ki hoʻo [[Special:Watchlist|hokohoko leʻo]]. Ko e ngaahi liliu ʻo e kahaʻu ʻi he pēsí ni mo hono peesi aleá, ʻe ʻoatu ʻi heni mo ʻasi mai  ʻi he hokohoko ʻo e [[Special:RecentChanges|ngaahi toki liliu]], ʻoku sinolahi ke fanāfotu.

Kapau ʻaho ʻe taha, te ke fietoʻo ʻa e pēsí mei hoʻo hokohoko leʻo, lomiʻi "taʻeleʻo" ʻi he pā tafaʻaki.',
'removedwatchtext'     => 'Kuo toʻo ʻa e peesi "[[:$1]]" mei hoʻo hokohoko leʻo.',
'watch'                => 'Leʻo',
'watchthispage'        => 'Leʻo he pēsí ni',
'unwatch'              => 'Taʻeleʻo',
'unwatchthispage'      => 'Tuʻu he leʻo',
'watchnochange'        => 'ʻOku ʻikai ʻaupito ʻe fatuʻi hoʻo ngaahi kupu fakaleʻo lolotonga ha taimi ʻoku ʻasi mai.',
'watchlist-details'    => 'ʻOku leʻoʻi ʻa e peesi ʻe $1, ʻikai kau ki ai ʻa e ngaahi peesi alea.',
'wlheader-enotif'      => 'Kuo fakamafeiaʻi tala mei he tohila',
'wlheader-showupdated' => '*Ko e ngaahi peesi kuo liliu talu he taimi hoʻo ʻaʻahi ki ai, ʻoku ʻasi mai fakasinolahi',
'watchmethod-recent'   => 'ʻoku siviʻi ngaahi toki fatu ki he peesi fakaleʻo',
'watchmethod-list'     => 'ʻoku siviʻi ʻa e ngaahi peesi fakaleʻo ki he toki fatu',
'watchlistcontains'    => 'ʻOku ʻi ai ha peesi ʻe $1 ʻi hoʻo hokohoko leʻo.',
'iteminvalidname'      => "Meʻa fihi mo e meʻa '$1', hingo taʻeʻaongaʻi...",
'wlnote'               => 'ʻOku ʻasi ʻi lalo ʻa e liliu fakamuimui ʻe $1 ʻi he houa fakamuimui ʻe <b>$2</b>.',
'wlshowlast'           => 'ʻAsi mai houa fakamuimui ʻe $1, ʻaho ʻe $2, $3',

# Displayed when you click the "watch" button and it is in the process of watching
'watching'   => 'ʻOku leʻo...',
'unwatching' => 'ʻOku taʻeleʻo...',

'enotif_newpagetext' => 'Ko e peesi foʻou ia.',
'changed'            => 'ʻosi liliu',
'created'            => 'kuo fakatupu',

# Delete
'deletepage'        => 'Tāmateʻi peesi',
'confirm'           => 'Fakamoʻoniʻi',
'excontent'         => "ko e kakano naʻe: '$1'",
'excontentauthor'   => "ko e kakano naʻe: '$1', mei he ʻetita ʻe taha pē: '[[Special:Contributions/$2|$2]]'",
'exbeforeblank'     => "ko e kakano ʻi muʻa ʻene fakaʻatā naʻe: '$1'",
'exblank'           => 'Naʻe maha ʻa e peesi',
'historywarning'    => 'Tokanga: ko e peesi te ke fietāmateʻi, ʻoku ʻi ai haʻane histolia.',
'confirmdeletetext' => 'Te ke tāmateʻi, ʻikai ala fūlihi, ʻa e peesi pe faitā mo hono hisitōlia kātoa mei he tānekingaʻilo. Kātaki fakamoʻoniʻi ʻoku sai ia, ʻoku ke ʻilo ʻa e fua, pea ʻoku ke fai pehē ototaha ia mo e [[{{MediaWiki:Policy-url}}]].',
'actioncomplete'    => 'ʻOsi ngāue',
'deletedtext'       => 'Kuo tāmateʻi "$1"
Vakai ki he $2 maʻa e fakamatala ʻo e ngaahi toki tāmateʻi.',
'dellogpage'        => 'Tohinoa ʻo e tāmateʻi',
'dellogpagetext'    => 'ʻOku ʻasi ʻi lalo ha hokohoko ʻo e ngaahi tāmateʻi fakamuimui taha.',
'deletionlog'       => 'tohinoa ʻo e tāmateʻi',
'reverted'          => 'Kuo foki ki he paaki mui',
'deletecomment'     => 'ʻUhinga',

# Rollback
'rollback'       => 'Ngaahi fatu he teka hifo',
'rollback_short' => 'Teka hifo',
'rollbacklink'   => 'teka hifo',
'rollbackfailed' => 'Halaʻi teka hifo',
'cantrollback'   => 'Naʻe ʻikai lava fakafoki ʻa e fatu; ko e ʻetita fakamuimui ko e ʻetita ʻe taha pē ʻo e pēsí ni.',
'alreadyrolled'  => 'ʻOku ʻikai lava teka hifo ʻa e fatu fakamuimui ʻo e [[:$1]] ʻe [[User:$2|$2]] ([[User talk:$2|Alea]]); ko e tokotaha ʻe taha naʻe fatu pe fatu teka hifo ʻa e peesi.

Ko e fatu fakamuimui naʻe fatu ʻe [[User:$3|$3]] ([[User talk:$3|Alea]]).',
'editcomment'    => "Ko e fakamatala fatu naʻe \"''\$1''\" ia.",

# Protect
'protectlogpage'      => 'Tohinoa ʻo e maluʻi',
'protectlogtext'      => 'ʻOku ʻasi ʻi lalo ha hokohoko ʻo e ngaahi loka mo e taʻeloka fakapeesi.',
'protectedarticle'    => 'maluʻi: "[[$1]]"',
'unprotectedarticle'  => 'taʻemaluʻi "[[$1]]"',
'protect-title'       => 'ʻOku maluʻi "$1"',
'prot_1movedto2'      => 'Kuo ʻunu ʻa e [[$1]] ki he [[$2]]',
'protect-legend'      => 'Fakamoʻoniʻi e maluʻi',
'protectcomment'      => 'ʻUhinga',
'protect-level-sysop' => 'Kau pule fakafounga pē',

# Restrictions (nouns)
'restriction-edit' => 'Fatu',
'restriction-move' => 'ʻUnu',

# Undelete
'undelete'           => 'Vakai ki he ngaahi peesi kuo tāmateʻi',
'undeletepage'       => 'Vakai pea fakafoki ngaahi peesi ʻosi tāmateʻi',
'viewdeletedpage'    => 'Vakai ki he ngaahi peesi kuo tāmateʻi',
'undeleterevisions'  => 'Ngaahi paaki ʻe $1 kuo ʻave ki he tauhiʻanga',
'undeletebtn'        => 'Fakafoki',
'undeletelink'       => 'fakafoki',
'undeletereset'      => 'Fakafoki',
'undeletecomment'    => 'Fakamatala:',
'undeletedrevisions' => 'Kuo fakafoki ʻa e paaki ʻe $1',
'undeletedfiles'     => 'Kuo fakafoki ʻa e faile ʻe $1',
'cannotundelete'     => 'Naʻe movete ʻa e taʻetāmateʻi; mahalo pē kuo taʻetāmateʻi ʻuluaki ia ʻe he ʻetita kehe.',
'undeletedpage'      => "'''Kuo fakafoki ko e $1'''

Vakai ki he [[Special:Log/delete|hokohoko tāmateʻi]] ki he lekooti ʻo e ngaahi tāmateʻi mo e taʻetāmateʻi onopooni.",

# Namespace form on various pages
'namespace'      => 'Vā hingoa:',
'invert'         => 'Fulihi hoʻo fili',
'blanknamespace' => '(Kupu)',

# Contributions
'contributions' => 'Ngaahi foaki ʻo e ʻetitá',
'mycontris'     => 'Foaki ʻaʻaku',
'uctop'         => ' (ʻi ʻolunga)',

'sp-contributions-deleted' => 'Ngaahi foaki ʻo ha ʻetita kuo tāmateʻi',
'sp-contributions-talk'    => 'Alea',

# What links here
'whatlinkshere'       => 'Ngaahi fehokotaki ki heni',
'linkshere'           => 'ʻOku fehokotaki ki heni ʻa e ngaahi peesi:',
'nolinkshere'         => 'ʻOku ʻikai ha ngaahi kupu fehokotaki ki heni.',
'isredirect'          => 'Peesi leʻei',
'istemplate'          => 'kātoi',
'whatlinkshere-links' => '← fehokotaki',

# Block/unblock
'blockip'              => 'Taʻofia ʻa e ʻetita',
'blockiptext'          => 'Ngāueʻaki ʻa e foomu ʻi lalo ʻe taʻofia ʻa e ngofua tohi ʻo e tuʻasila IP pe hingoa ʻetita ʻe taha. ʻOku pau ʻe fai pehē ʻi he taʻofi laukovi pē, lototaha ia mo e [[{{MediaWiki:Policy-url}}|founga]]. Fakafonu ʻi lalo ʻa e ʻuhinga totonu (fakafuaʻaki, lau ki he ngaahi peesi naʻe laukovi).',
'ipadressorusername'   => 'Tuʻasila IP pe hingoa ʻo e ʻetita',
'ipbexpiry'            => 'Mate',
'ipbreason'            => 'ʻUhinga',
'ipbcreateaccount'     => 'Taʻofia ʻa e fakatupu ʻo ha tohi kau-ki-ai',
'ipbsubmit'            => 'Taʻofia ʻa e ʻetitá ni',
'ipbother'             => 'Fuoloa kehe',
'ipbotheroption'       => 'kehe',
'badipaddress'         => 'Tuʻasila IP taʻeʻaongaʻi',
'blockipsuccesssub'    => 'Ola ʻo e taʻofi',
'blockipsuccesstext'   => 'Kuo taʻofia ʻa [[Special:Contributions/$1|$1]]
<br />Vakai ki he [[Special:BlockList|hokohoko ʻo e taʻofi]] ʻo toe fakakaukau ʻi ai.',
'unblockip'            => 'Taʻetaʻofia ʻetita',
'unblockiptext'        => 'Ngāueʻaki ʻa e foomu ʻi lalo ke fakafoki e ngofua tohi maʻa e tuʻasila IP pe hingoa ʻo e kau-ki-ai ʻosi taʻofi.',
'ipusubmit'            => 'Taʻetaʻofia ʻa e ʻetitá ni',
'unblocked'            => 'Kuo taʻetaʻofia ʻa [[User:$1|$1]]',
'ipblocklist'          => 'Hokohoko ʻo e ngaahi tuʻasila IP mo e hingoa ʻo e ʻetita kuo taʻofi',
'infiniteblock'        => 'taʻengata',
'expiringblock'        => 'ʻE mate ia $1 $2',
'anononlyblock'        => 'taʻehingoa pē',
'createaccountblock'   => 'ʻOku taʻofia ʻa e fakatupu ʻa e tohi-kau-ki-ai',
'blocklink'            => 'taʻofi',
'unblocklink'          => 'taʻetaʻofi',
'contribslink'         => 'foaki',
'autoblocker'          => 'ʻOku taʻofi ʻiate ia pe, koeʻuhi ko hoʻo tuaʻasila IP naʻe ngāueʻaki ia ʻe he ʻetita "[[User:$1|$1]]". Ko e ʻuhinga maʻa e taʻofi ʻo $1 ko "\'\'\'$2\'\'\'" ia.',
'blocklogpage'         => 'Tohinoa ʻo e taʻofi',
'blocklogentry'        => 'taʻofia [[$1]] mo ha fuoloa $2 $3',
'blocklogtext'         => 'Ko e tohinoa ʻeni ʻo e ngāue ʻo e ngaahi taʻofi mo e taʻetaʻofi ʻo e kau ʻetita. ʻOku ʻikai ʻasi ha ngaahi tuʻasila IP ʻoku taʻofi ngaue ʻia te ia pē. Vakai ki he [[Special:BlockList|hokohoko taʻofi IP]] kapau te ke fiemaʻu ʻa e hokohoko ʻo e ngaahi taʻofi taka kotoa.',
'unblocklogentry'      => 'taʻetaʻofia $1',
'range_block_disabled' => 'ʻOku fakataʻeʻaongaʻi ʻa e fakatupu fakapule-fakafounga ʻo ngaahi taʻofi fakavā.',
'ipb_expiry_invalid'   => 'ʻOku taʻeʻaongaʻi ʻa e taimi ki he mate.',
'ipb_already_blocked'  => 'Kuo ʻosi taʻofi ʻa e "$1"',
'ipb_cant_unblock'     => 'Hala: naʻe ʻikai ʻilo ko e taʻofi fika $1. Mahalo pē kuo ʻosi ʻene taʻetaʻofi.',
'ip_range_invalid'     => 'ʻOku taʻeʻaonga ʻa e fakavā IP',
'proxyblocksuccess'    => 'Kuo fai.',

# Developer tools
'lockdb'              => 'Lokaʻi ʻa e tānekingaʻilo',
'unlockdb'            => 'Taʻelokaʻi ʻa e tānekingaʻilo',
'lockdbtext'          => 'Kapau te ke lokaʻi ʻa e tānekingaʻilo, ʻe ʻikai lava ʻa e kau ʻetita kotoa e fatu peesi, liliu ʻenau faʻiteliha, ʻetita ʻenau hokohoko leʻo, mo e hā fua. Kātaki tala mai ko ia pē ʻoku ke fiefai, pea te ke taʻelokaʻi ʻa e tānekingaʻilo ʻosi hoʻo ngāue monomono.',
'unlockdbtext'        => 'Kapau te ke taʻelokaʻi ʻa e tānekingaʻilo, ʻe lava ʻa e kau ʻetita kotoa e fatu peesi, liliu ʻenau faʻiteliha, ʻetita ʻenau hokohoko leʻo, mo e hā fua. Kātaki tala mai ko ia pē ʻoku ke fiefai.',
'lockconfirm'         => 'ʻIo, ʻoku moʻoni ke u fielokaʻi ʻa e tānekingaʻilo.',
'unlockconfirm'       => 'ʻIo, ʻoku moʻoni ke u fietaʻelokaʻi ʻa e tānekingaʻilo.',
'lockbtn'             => 'Lokaʻi tānekingaʻilo',
'unlockbtn'           => 'Taʻelokaʻi tānekingaʻilo',
'locknoconfirm'       => 'Naʻe ʻikai te ke tiki ʻa e puha fakapapauʻi.',
'unlockdbsuccesssub'  => 'Kuo toʻo ʻa e loka ʻo e tānekingaʻilo.',
'lockdbsuccesstext'   => 'Kuo lokaʻi ʻa e tānekingaʻilo.

ʻE manatuʻi koe te ke ʻe taʻelokaʻi ʻa e tānekingaʻilo ʻosi hoʻo ngāue monomono.',
'unlockdbsuccesstext' => 'Kuo taʻeloka ʻa e tānekingaʻilo.',
'databasenotlocked'   => 'ʻOku ʻikai lokaʻi ʻa e tānekingaʻilo',

# Move page
'move-page-legend'        => 'Peesi ʻunu',
'movepagetext'            => "Ngāueʻaki ʻa e foomu ʻi lalo, ʻe toe fakahingoaʻi ʻa e pēsí mo hono hisitōliá.
ʻE hoko ʻa e hingoa motuʻa ki he peesi leʻei ki he hingoa foʻou.
ʻE ʻikai liliu ʻa e ngaahi fehokotaki ki he hingoa motuʻa, e taau te ke sivi ʻa e leʻeleʻei mo e leʻei maumau. Ko ho fatongia ʻe tuhu ai pē ngaahi fehokotaki ki ʻenau peesi totonu.

ʻE ʻikai ʻunuʻi ʻa e peesi kapau ʻoku toe ʻi ai ha peesi mo e hingoa foʻou tatau, ngata pē ʻoka ʻi ai ha peesi taʻetohitohiʻi pe leʻei mo e ʻikai ha hisitōlia. Ko ia ai: ʻe lava te ke toe fakahingoa ʻa e peesi mei he hingoa motuʻa, kapu te ke hala, mo: ʻe ʻikai te ke lava tohi ke maumau ʻa e peesi ʻoku tuʻu.

'''TOKANGA!''' Mahalo pē ʻe ʻi ai ha liliu mālohi kapau ʻoku manakoa ʻa e pēsí ni. ʻIlo ko e hā te ke fie fai. Kapau ʻikai pau, ʻoku sai ange ʻe ʻikai te ke fakaʻunu.",
'movepagetalktext'        => "Ko e peesi alea ʻoku kau ki he pēsí ni, ʻe ʻunu ia mo e hono hoa, '''ngata pē ʻoka:'''
*ha peesi ʻikai maha ʻoku toka tuʻu mo e hingoa tatau, pe
*te ke tiki ʻa e puha ʻi lalo.
ʻI he meʻa ko ia, ʻe ʻunuʻi pe fakatahaʻi ʻa e peesi alea faiʻaki ʻa e nima.",
'movearticle'             => 'ʻUnu ʻa e kupu',
'movenologin'             => 'ʻOku ʻikai ke kau-ki-ai',
'movenologintext'         => 'Kuo pau ko e ʻetita lēsisita koe pea [[Special:UserLogin|kau-ki-ai]] kapau te ke fieʻunu ha peesi.',
'newtitle'                => 'Ki he hingoa foʻou',
'move-watch'              => 'Leʻo he pēsí ni',
'movepagebtn'             => 'Peesi ʻunu',
'pagemovedsub'            => 'Kuo ola ʻa e ʻunu',
'articleexists'           => 'ʻOku toka ʻi ai ha peesi mo e hingoa ē, pe ʻoku ʻikai sai ʻa e hingoa ʻoku ke fiemaʻu. Kātaki fili ha hingoa kehe.',
'talkexists'              => "'''Kuo ola ʻa e ʻunu ʻo e peesi ia, kā naʻe ʻikai ʻunu he peesi alea koeʻuhi ʻoku toe tuʻu ha peesi pehē mo e hingoa foʻou. Kātaki fakataha kinaua faiʻaki ʻa e nima.'''",
'movedto'                 => 'kuo ʻunu ki he',
'movetalk'                => 'ʻUnu he peesi alea fekauʻaki',
'movelogpage'             => 'Tohinoa ʻo e ʻunu',
'movelogpagetext'         => 'Ko e hokohoko ʻo e ngaahi peesi kuo ʻunu',
'movereason'              => 'ʻUhinga',
'revertmove'              => 'foki ki he paaki motuʻa',
'delete_and_move'         => 'Tāmateʻi pea ʻunu',
'delete_and_move_text'    => '==Fiemaʻu tāmateʻi==

ʻOku toka tuʻu ʻa e kupu pehē "[[:$1]]". ʻOku ke fietāmateʻi ia ke fakaʻatā he ʻunu?',
'delete_and_move_confirm' => 'ʻIo, tāmateʻi e pēsí',
'delete_and_move_reason'  => 'Kuo tāmateʻi maʻa e fakaʻatā he ʻunu',

# Export
'export'        => 'Hū atu ko e ngaahi peesi',
'exportcuronly' => 'Fālute ko e paaki onopooni pē, kae ʻikai ko e hisitōlia kātoa',
'export-submit' => 'Hū atu',

# Namespace 8 related
'allmessages'               => 'Tala fakafounga',
'allmessagesname'           => 'Hingoa',
'allmessagesdefault'        => 'Tohi tuʻunga',
'allmessagescurrent'        => 'Tohi lolotonga',
'allmessagestext'           => "Ko e hokohoko ʻeni ʻo e ngaahi tala fakafounga kātoa ʻi he vā hingoa ''MediaWiki''.",
'allmessagesnotsupportedDB' => "ʻOku ʻikai ngāueʻaki mo e '''{{ns:special}}:Allmessages''' koeʻuhi ʻoku kamosiʻi mate ʻa e '''\$wgUseDatabaseMessages'''.",

# Thumbnails
'filemissing' => 'ʻOku pulia ʻa e faile',

# Special:Import
'import'                     => 'Hū mai ngaahi peesi',
'importinterwiki'            => "Hū mai ʻo e fakalava ''wiki''",
'import-interwiki-history'   => 'Hiki ko e paaki hisitōlia kotoa maʻa e pēsí ni',
'import-interwiki-submit'    => 'Hū mai',
'import-interwiki-namespace' => 'ʻAve ngaahi peesi ki he vā hingoa:',
'import-comment'             => 'Fakamatala:',
'importtext'                 => "Kātaki ʻe hū atu ʻa e faile mei he ''wiki'' tupunga ngāueʻaki ''Special:Export'', pea haofakiʻi ʻi hoʻo tisi, pea hū mai ia mei hē.",
'importstart'                => 'Hū mai ngaahi peesi...',
'import-revision-count'      => 'Paaki ʻe $1',
'importnopages'              => 'ʻOku ʻikai ha ngaahi peesi ʻoku hū mai ai.',
'importfailed'               => 'Halaʻi hū mai: $1',
'importunknownsource'        => 'Ko e falenga hū mai taʻeʻiloa',
'importnotext'               => 'Maha pe ʻikai ha mataʻitohi',
'importsuccess'              => 'Kuo ola ʻa e hū mai!',
'importnosources'            => "Naʻe ʻikai fakaʻuhingaʻi ha ngaahi hūmai fakalava ''wiki'' pea ʻoku fakataʻeʻaongaʻi  ngaahi hiki hake fakahisitōlia.",
'importnofile'               => 'Naʻe ʻikai fekahekaʻi hake ha faile hūmai.',

# Import log
'importlogpage'                 => 'Tohinoa ʻo e hūmai',
'importlogpagetext'             => "Ko e ngaahi hūmai fakapule mo e honau hisitōlia fatu mei he ngaahi ''wiki'' kehe.",
'import-logentry-upload-detail' => 'paaki ʻe $1',

# Tooltip help for the actions
'tooltip-pt-mytalk'        => 'Ko e peesi alea ʻaʻau',
'tooltip-pt-logout'        => 'ʻAlu mamaʻo',
'tooltip-search'           => "Kumi ''{{SITENAME}}''",
'tooltip-t-whatlinkshere'  => 'Ko e hokohoko ʻo e ngaahi kupu ʻoku nau fehokotaki ki heni',
'tooltip-feed-rss'         => "Lave ''RSS'' maʻa e pēsí ni",
'tooltip-feed-atom'        => "Lave ''Atom'' maʻa e pēsí ni",
'tooltip-t-upload'         => 'Hiki hake ʻa e ngaahi faile',
'tooltip-ca-nstab-special' => 'Ko e peesi makehe ia, ʻoku ʻikai lava te ke fatu ia ʻe koe',
'tooltip-undo'             => '"Vete" ʻoku toe foki ʻa e fatu ni pea fakaava ʻa e foomu fatu ʻi he anga siomuʻa.
Pea hoko ai pē hoʻo lava tānaki ha ʻuhinga ʻi he fakanounou',

# Metadata
'notacceptable' => "ʻOku ʻikai lava fakaai ʻe he tauhia 'wiki' ʻa e meʻaʻilo ʻi he meʻangaohi ʻoku lava lau ʻe koe.",

# Attribution
'anonymous'   => 'Kau ʻetita taʻehingoa ʻo e {{SITENAME}}',
'siteuser'    => 'Ko e ʻetita {{SITENAME}} $1',
'others'      => 'ngaahi toe',
'siteusers'   => 'Kau ʻetita {{SITENAME}} $1',
'creditspage' => 'Peesi fakangeiaʻi',

# Spam protection
'spamprotectionmatch' => 'Naʻe kamosi ʻemau meʻasivi tohila ʻe he ngaahi mataʻitohi koʻeni: $1',

# Patrolling
'rcpatroldisabled' => 'ʻOku fakataʻeʻaʻongaʻi ʻa e leʻo ʻo e ngaahi toki liliu',

# Image deletion
'deletedrevision' => 'Kuo tāmateʻi he paaki motuʻa $1.',

# Browsing diffs
'previousdiff' => '← Faikehe ki muʻa',
'nextdiff'     => 'Faikehe hoko →',

# Media information
'imagemaxsize'   => 'Fakangatangata ngaahi faitā ʻi he ʻū peesi fakamahino ki he:',
'file-info'      => 'Ko e faile hono lahi: $1, faʻahinga MIME: $2',
'file-nohires'   => 'ʻOku ʻikai ʻi ai ha faitā auiiki.',
'show-big-image' => 'ʻAsi ʻa e faitā auiiki',

# Special:NewFiles
'newimages'             => 'Fakaʻaliʻali ʻo e ngaahi faitā foʻou',
'imagelisttext'         => "ʻOku ʻasi ʻi lalo ha hokohoko ʻo e '''$1''' vahevahe he $2.",
'showhidebots'          => '($1 fatu fakamīsini)',
'noimages'              => 'ʻOku ʻikai ha meʻa ke sio ki ai.',
'ilsubmit'              => 'Kumi',
'bydate'                => 'ʻi honau ʻaho',
'sp-newimages-showfrom' => 'ʻAsi mai ha ngaahi faitā foʻou ʻoku kamata mei he $1',

# Metadata
'metadata-expand'   => 'Fano kiʻi meʻa',
'metadata-collapse' => 'Holo kiʻi meʻa',

# EXIF tags
'exif-xresolution'                 => 'Auiiki fakalava',
'exif-yresolution'                 => 'Auiiki tuʻutonu',
'exif-jpeginterchangeformatlength' => 'ʻŪ valu meʻaʻilo JPEG',
'exif-make'                        => 'Ko e tokotaha faʻu ʻo e meʻafaitā',
'exif-artist'                      => 'Tokotaha faitā',
'exif-usercomment'                 => 'Fakamatala ʻo e ʻetita',
'exif-brightnessvalue'             => 'Ngingila',
'exif-lightsource'                 => 'Malama',
'exif-flash'                       => 'Tapa',
'exif-focallength'                 => 'Lōloa ʻesiafi ʻo e sioʻata ʻesiafi',
'exif-focallength-format'          => 'milimita ʻe $1',
'exif-flashenergy'                 => 'Ivi ʻo e tapa',
'exif-focalplanexresolution'       => 'Auiiki X ʻi he lafalafa ʻesiafi',
'exif-focalplaneyresolution'       => 'Auiiki Y ʻi he lafalafa ʻesiafi',
'exif-focalplaneresolutionunit'    => 'ʻUniti auiiki ʻi he lafalafa ʻesiafi',
'exif-customrendered'              => 'Faitā ʻene angafai',
'exif-focallengthin35mmfilm'       => 'Lōloa ʻesiafi ʻi he filimi milimita ʻe 35',
'exif-gaincontrol'                 => 'Puleʻi mātanga',
'exif-contrast'                    => 'Faikehekehe',
'exif-saturation'                  => 'Lanufakangahū',
'exif-sharpness'                   => 'Faitā hono mataʻāʻā',
'exif-gpsversionid'                => 'Fika fakapaaki FTM',
'exif-gpslatituderef'              => 'Latitute tonga pe tokelau',
'exif-gpslatitude'                 => 'Latitute',
'exif-gpslongituderef'             => 'Longitute hahake pe hihifo',
'exif-gpslongitude'                => 'Longitute',
'exif-gpsaltituderef'              => 'Māʻolunga hono tuʻunga',
'exif-gpsaltitude'                 => 'Māʻolunga',
'exif-gpstimestamp'                => 'Taimi FTM (uasi fakaʻātomi)',
'exif-gpsspeed'                    => 'Ko e vave ʻo e meʻa fakafanongo FTM',
'exif-gpsdestlatituderef'          => 'Tuʻunga maʻa e latitute ʻo e taumuʻa',
'exif-gpsdestlatitude'             => 'Latitute ʻo e taumuʻa',
'exif-gpsdestlongituderef'         => 'Tuʻunga maʻa e longitute ʻo e taumuʻa',
'exif-gpsdestlongitude'            => 'Longitute ʻo e taumuʻa',
'exif-gpsdestbearingref'           => 'Tuʻunga maʻa e tūkufua ʻo e taumuʻa',
'exif-gpsdestbearing'              => 'Tūkufua ʻo e taumuʻa',
'exif-gpsdestdistanceref'          => 'Tuʻunga maʻa e mamaʻo ʻo e taumuʻa',
'exif-gpsdestdistance'             => 'Mamaʻo ʻo e taumuʻa',
'exif-gpsprocessingmethod'         => 'Hingoa ʻo e angafai FTM',
'exif-gpsareainformation'          => 'Hingoa ʻo e feituʻu FTM',
'exif-gpsdatestamp'                => 'ʻAho FTM',
'exif-gpsdifferential'             => 'Fakatonutonu fakafaikehekehe FTM',

'exif-planarconfiguration-1' => 'ngaohi konga noa pē',
'exif-planarconfiguration-2' => 'ngaohi laini kotoa pē',

'exif-componentsconfiguration-0' => 'ʻoku ʻikai ʻi ai',

'exif-subjectdistance-value' => 'mita ʻe $1',

'exif-lightsource-0'   => 'Taʻeʻiloa',
'exif-lightsource-1'   => 'ʻAho',
'exif-lightsource-2'   => 'Uloʻi ngingila',
'exif-lightsource-3'   => 'Uloʻi afi',
'exif-lightsource-4'   => 'Tapa',
'exif-lightsource-9'   => 'ʻAlomālie',
'exif-lightsource-10'  => 'ʻAoʻaofia',
'exif-lightsource-11'  => 'Malumalu',
'exif-lightsource-12'  => 'Ulo ʻaho (D 5700 – 7100K)',
'exif-lightsource-13'  => 'Ulo ʻaho hinehina (N 4600 – 5400K)',
'exif-lightsource-14'  => 'Ulo hinehina fakamomoko (W 3900 – 4500K)',
'exif-lightsource-15'  => 'Ulo hinehina (WW 3200 – 3700K)',
'exif-lightsource-17'  => 'Ulo tuʻunga A',
'exif-lightsource-18'  => 'Ulo tuʻunga B',
'exif-lightsource-19'  => 'Ulo tuʻunga C',
'exif-lightsource-24'  => 'Uloʻi afi faitāʻanga ISO',
'exif-lightsource-255' => 'Malama kehe',

'exif-customrendered-0' => 'Faitā angatotonu',
'exif-customrendered-1' => 'Fai ʻi heʻene angafai',

'exif-gaincontrol-0' => 'Hala',
'exif-gaincontrol-1' => 'Hake tupu fakalalo',
'exif-gaincontrol-2' => 'Hake tupu fakaʻolunga',
'exif-gaincontrol-3' => 'Hifo tupu fakalalo',
'exif-gaincontrol-4' => 'Hifo tupu fakaʻolunga',

'exif-contrast-0' => 'Faitotonu',
'exif-contrast-1' => 'Vaivai',
'exif-contrast-2' => 'Mālohi',

'exif-saturation-0' => 'Lanufakangahū noa pē',
'exif-saturation-1' => 'Lanufakangahū siʻi',
'exif-saturation-2' => 'Lanufakangahū lahi',

'exif-sharpness-0' => 'Matanoa',
'exif-sharpness-1' => 'Matanenefu',
'exif-sharpness-2' => 'Matatoki',

# Pseudotags used for GPSLatitudeRef and GPSDestLatitudeRef
'exif-gpslatitude-n' => 'Latitute tokelau',
'exif-gpslatitude-s' => 'Latitute tonga',

# Pseudotags used for GPSLongitudeRef and GPSDestLongitudeRef
'exif-gpslongitude-e' => 'Longitute hahake',
'exif-gpslongitude-w' => 'Longitute hihifo',

# Pseudotags used for GPSSpeedRef
'exif-gpsspeed-k' => 'Kilomita ki he houa',
'exif-gpsspeed-m' => 'Maile he houa',

# Pseudotags used for GPSTrackRef, GPSImgDirectionRef and GPSDestBearingRef
'exif-gpsdirection-t' => 'Tūkufua moʻoni',
'exif-gpsdirection-m' => 'Tūkufua fakamakineti',

# External editor support
'edit-externally'      => 'Fatuʻi ʻa e failé ni ngāueʻaki mo e polokalama ʻi tuʻa',
'edit-externally-help' => 'Vakai ki he [//www.mediawiki.org/wiki/Manual:External_editors fakahinohino ki he fokotuʻu] maʻa toe fakamatala.',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'kātoa',
'namespacesall' => 'vā kotoa',

# E-mail address confirmation
'confirmemail'            => 'Fakamoʻoniʻi ho tuʻasila tohila',
'confirmemail_noemail'    => 'Naʻe ʻikai te ke fakamoʻoniʻi ʻa e tohila totonu ʻi he [[Special:Preferences|faʻiteliha ʻaʻau]].',
'confirmemail_text'       => 'Kuo pau te ke fakamoʻoniʻi ho tuʻasila tohila ki muʻa ʻi hoʻo ngāueʻaki ʻa e ngaahi fōtunga tohila. Lomiʻi ʻa e meʻalolomi ʻi lalo pea ʻe ʻavea ha tohila fakamoʻoniʻi ki ho tuʻasila. ʻE ʻi ai ha fehokotaki mo ha lea fakapulipuli ʻi ai. Fafaʻo ʻa e fehokotakí ni ʻi hoʻo palausa ke fakamoʻoniʻi ʻoku sai ho tuʻasila tohila.',
'confirmemail_send'       => 'ʻAve ha lea fakapulipuli',
'confirmemail_sent'       => 'Kuo ʻave ʻa e tohila fakamoʻoniʻi.',
'confirmemail_sendfailed' => 'Naʻe ʻikai lava ʻe ʻave ha tohila fakamoʻoniʻi. Sivi ho tuʻasila ʻoku sai ia.

Mailer returned: $1',
'confirmemail_invalid'    => 'ʻOku taʻeʻaonga e fakamoʻoniʻi tohila, mahalo pē ʻosi mate ʻa e lea fakapulipuli.',
'confirmemail_needlogin'  => 'ʻOku pau te ke $1, koeʻuhi ʻe fakamoʻoniʻi ho tuʻasila tohila.',
'confirmemail_success'    => 'Kuo fakamoʻoniʻi ho tuʻasila tohila. ʻOku lava ke ke kau-ki-ai pea huaʻia ʻa e wiki.',
'confirmemail_loggedin'   => 'He taimí ni kuo fakamoʻoniʻi ho tuʻasila tohila.',
'confirmemail_error'      => 'Ko e meʻa hala ʻi he haofaki ʻo e hoʻo fakamoʻoniʻi tohila.',
'confirmemail_subject'    => 'Ko e fakamoʻoniʻi ʻo e tuʻasila tohila ʻo e {{SITENAME}}',
'confirmemail_body'       => 'Ko e tokotaha, mahalo pē ko koe mei he tuʻasila IP $1, naʻe lēsisita ia ha tohi kau-ki-ai "$2" mo e tuʻasila tohilá ni ʻi {{SITENAME}}.

ʻE fakamoʻoniʻi ʻa e tohí ni mo e fakamoʻui ʻene tohila ʻi {{SITENAME}}, kapau ʻoku moʻoni ʻene ʻave meiate koe, ʻe fakaava ʻa e fehokotakí ni ʻi hoʻo palausa:

$3

Kapau ʻoku ʻikai ko koe, ʻoua ʻe fakaava ia. ʻE mate ʻa e lea fakapulipulí ni he $4.',

# Scary transclusion
'scarytranscludefailed' => '[Fakamolemole, naʻe movete maʻu he sīpinga maʻa e $1]',

# Delete conflict
'deletedwhileediting' => 'Tokanga: Naʻe tāmateʻi he pēsí ni ʻosi hoʻo kamataʻanga tohi!',
'confirmrecreate'     => "Naʻe tāmateʻi ʻa e kupu ko ʻeni ʻe he ngāue [[User:$1|$1]] ([[User talk:$1|alea]]) hili hoʻo kamataʻanga fatu.
: Ko e ʻuhinga: ''$2''
Kātaki fakapapauʻi te ke fie toe fatu ʻa e kupu ni.",
'recreate'            => 'Toe fakatupu',

# action=purge
'confirm_purge_button' => 'Fai ā',
'confirm-purge-top'    => 'Fakaʻatā ko e fafaʻo ʻo e pēsí ni?',

# Multipage image navigation
'imgmultipageprev' => '← Peesi ki muʻa',
'imgmultipagenext' => 'Peesi hoko →',
'imgmultigo'       => 'Fai ā!',

# Table pager
'ascending_abbrev'         => 'hake',
'descending_abbrev'        => 'hifo',
'table_pager_next'         => 'Peesi hoko',
'table_pager_prev'         => 'Peesi ki muʻa',
'table_pager_first'        => 'Peesi ʻuluaki',
'table_pager_last'         => 'Peesi fakaʻosi',
'table_pager_limit'        => 'ʻAsi mai meʻa ʻe $1 ki he peesi.',
'table_pager_limit_submit' => 'Fai ā',
'table_pager_empty'        => 'ʻIkai ha ola',

# Auto-summaries
'autoredircomment' => 'ʻOku leʻei ki he [[$1]]',

# Watchlist editing tools
'watchlisttools-view' => 'Sio ki he ngaahi liliu maʻongoʻonga',
'watchlisttools-edit' => 'Sio pea fatu ʻete hokohoko leʻo',
'watchlisttools-raw'  => 'Fatu ʻa e hokohoko leʻo taʻengaohi',

# Special:Version
'version' => 'Paaki',

# Special:FilePath
'filepath'        => 'Hala ki he faile',
'filepath-page'   => 'Faile:',
'filepath-submit' => 'Ko e hala',

# Special:SpecialPages
'specialpages' => 'Ngaahi peesi makehe',

);
